# Changelog

Tüm önemli değişiklikler bu dosyada dokümante edilmiştir.

## [1.0.0] - 2025-01-11

### Added
- Tek ödeme modülü
- Devre sonu/başı anüiteler
- Sürekli anüiteler
- Ertelenmiş anüiteler
- Geometrik ve aritmetik anüiteler
- Çabuklaştırılmış anüiteler
- 150+ matematiksel fonksiyon
- Kapsamlı test paketi
- Türkçe dokümantasyon

### Features
- Bugünkü değer ve gelecek değer hesaplamaları
- Ters formüller (parametreleri hesaplama)
- Amortisman tablosu oluşturma
- Faiz oranı çevrimleri
- NPV ve IRR hesaplamaları
- Duration ve Convexity